@@ -28,12 +28,12 @@
 #include <lfcbase/SetT.h>
 #include <lfcbase/Datetime.h>
 #include <lfcbase/SigHandler.h>
-#include <lfcbase/Screen2.h>
+#include <lfcbase/Screen.h>
 
 #include "CegoAdminHandler.h"
 #include "CegoXMLdef.h"
 
-class CegoAdmScreen : public Screen2
+class CegoAdmScreen : public Screen
 {
     
 public:
@@ -47,11 +47,11 @@ private:
     // Buffer Pool Panel //
     ///////////////////////
     
-    class BufferPool : public Screen2::Attribute {
+    class BufferPool : public Screen::Attribute {
     public:
     
-	BufferPool(CegoAdminHandler* pAH, Screen2::Panel* pParent)
-	    : Screen2::Attribute(pParent, Attribute::OVERLAY) {
+	BufferPool(CegoAdminHandler* pAH, Screen::Panel* pParent)
+	    : Screen::Attribute(pParent, Attribute::OVERLAY) {
 	    _pAH = pAH;
 	}
 	
@@ -67,21 +67,21 @@ private:
     // Thread Pool Panel //
     ///////////////////////
     
-    class ThreadPool : public Screen2::Select {
+    class ThreadPool : public Screen::Select {
     public:
     
-	ThreadPool(CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);
-	Screen2::Panel* onSelect(int selected);
+	ThreadPool(CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);
+	Screen::Panel* onSelect(unsigned selected);
 	
     private:
 	
-	class DbPool : public Screen2::Grid {
+	class DbPool : public Screen::Grid {
 	public:
 	
-	    DbPool(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    DbPool(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ~DbPool();
-	    Screen2::Panel* onSelect(int rowNum);
-	    Screen2::Panel* onKey(int c, int rowNum);
+	    Screen::Panel* onSelect(unsigned rowNum);
+	    Screen::Panel* onKey(unsigned c, unsigned rowNum);
 	    
 	    ListT< ListT<Chain> > getData() { return _threadTable; };
 	    
@@ -90,17 +90,17 @@ private:
 	    
         private:
 	    
-	    class ThreadQuery : public Screen2::Grid {		
+	    class ThreadQuery : public Screen::Grid {		
 	    public:
 		
-		ThreadQuery(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		ThreadQuery(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~ThreadQuery();
 
 		void setTitle(const Chain& title);
 		void setHistory( ListT< ListT<Chain> >& queryHist);
 		void setQueryFull( ListT<Chain>& queryFull);
 		
-		Screen2::Panel* onSelect(int rowNum);
+		Screen::Panel* onSelect(unsigned rowNum);
 		
 		ListT< ListT<Chain> > getData() { return _queryTable; };
 		
@@ -109,13 +109,13 @@ private:
 		
 	    private:
 		
-		class QueryInfo : public Screen2::Message {
+		class QueryInfo : public Screen::Message {
 	        public:
 		    
-		    QueryInfo(Screen2::Panel* pParent) : Screen2::Message(pParent) {	
+		    QueryInfo(Screen::Panel* pParent) : Screen::Message(pParent) {	
 		    }
 		    
-		    void setQuery(const Chain& title, const Chain& msg, int numRow) {
+		    void setQuery(const Chain& title, const Chain& msg, unsigned numRow) {
 			setInfo(title, msg, numRow);
 		    }
 	        };
@@ -126,23 +126,23 @@ private:
 		ListT<Chain> _queryFull;		
 		ListT<Chain> _querySchema;
 		
-		int format(const Chain& query, Chain& formatted);
+		unsigned format(const Chain& query, Chain& formatted);
 		CegoAdminHandler *_pAH;
 	    };
 
-	    class ThreadAbort : public Screen2::Confirm {		
+	    class ThreadAbort : public Screen::Confirm {		
 	    public:
 
-		ThreadAbort(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		ThreadAbort(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~ThreadAbort();
-		void setup( int threadId);
-		Screen2::Panel* onConfirm();		
-		Screen2::Panel* onCancel() { return _pParent; }
+		void setup( unsigned threadId);
+		Screen::Panel* onConfirm();		
+		Screen::Panel* onCancel() { return _pParent; }
 	       	      
 	    private:
 
 		CegoAdminHandler *_pAH;
-		int _threadId;
+		unsigned _threadId;
 	    };
 
 	    void handleResult();
@@ -154,10 +154,10 @@ private:
 	    CegoAdminHandler* _pAH;
 	};
 	
-	class AdmPool : public Screen2::Grid {
+	class AdmPool : public Screen::Grid {
 	public:
 	    
-	    AdmPool(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    AdmPool(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ListT< ListT<Chain> > getData() { return _threadTable; };
 	    bool doRefresh() { return true; }
 	    void refresh();
@@ -169,10 +169,10 @@ private:
 	    CegoAdminHandler* _pAH;
 	};
 
-      	class LogPool : public Screen2::Grid {
+      	class LogPool : public Screen::Grid {
 	public:
 	    
-	    LogPool(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    LogPool(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ListT< ListT<Chain> > getData() { return _threadTable; };
 	    bool doRefresh() { return true; }
 	    void refresh();
@@ -194,53 +194,53 @@ private:
     // Tableset Panel //
     ////////////////////
 
-    class TableSet : public Screen2::Grid {
+    class TableSet : public Screen::Grid {
 	
     public:
 	
-	TableSet(CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);	
+	TableSet(CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);	
 	~TableSet();
-	Screen2::Panel* onSelect(int selected);
-	Screen2::Panel* onKey(int c, int rowNUm);
+	Screen::Panel* onSelect(unsigned selected);
+	Screen::Panel* onKey(unsigned c, unsigned rowNUm);
 	ListT< ListT<Chain> > getData() { return _tsTable; };
 	void refresh();
 	bool doRefresh() { return true; };
 	
     private:
 	
-	class Add : public Screen2::Form {
+	class Add : public Screen::Form {
 	public:
 	    
-	    Add(CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);	    
+	    Add(CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);	    
 	    ~Add();
 
-	    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
-	    Screen2::Panel* onCancel() { return _pParent;   }
+	    Screen::Panel* onConfirm(const ListT<Chain>& valList);
+	    Screen::Panel* onCancel() { return _pParent;   }
 	    
 	private:
 	    
 	    CegoAdminHandler* _pAH;	    
 	};
 
-	class Action : public Screen2::Select {
+	class Action : public Screen::Select {
 	public:
 	    
-	    Action(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    Action(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ~Action();	    
 	    void setTableSet(const Chain& tableSet, const Chain& tsState, const Chain& archMode);
-	    Screen2::Panel* onSelect(int selected);	    
+	    Screen::Panel* onSelect(unsigned selected);	    
 	    
 	private:
 
-	    class Edit : public Screen2::Form {
+	    class Edit : public Screen::Form {
 	    public:
 		
-		Edit(CegoAdminHandler* pAH, Screen2::Panel* pParent);	    
+		Edit(CegoAdminHandler* pAH, Screen::Panel* pParent);	    
 		~Edit();
 
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
-		Screen2::Panel* onCancel() { return _pParent;   }
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onCancel() { return _pParent;   }
 		
 	    private:
 
@@ -248,29 +248,29 @@ private:
 		CegoAdminHandler* _pAH;		
 	    };
 	    
-	    class Archlog : public Screen2::Grid {
+	    class Archlog : public Screen::Grid {
 	    public:
 		
-		Archlog(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Archlog(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Archlog();
 		void setup(const Chain& tableSet, const Chain& archMode);
-		Screen2::Panel* onSelect(int rowNum);
-		Screen2::Panel* onKey(int c, int rowNum);
+		Screen::Panel* onSelect(unsigned rowNum);
+		Screen::Panel* onKey(unsigned c, unsigned rowNum);
 		ListT< ListT<Chain> > getData();
 		void refresh();
 		bool doRefresh() { return true; };
 		
 	    private:
 		
-		class Add : public Screen2::Form {
+		class Add : public Screen::Form {
 		public:
 		    
-		    Add(CegoAdminHandler* pAH, Screen2::Panel* pParent);		
+		    Add(CegoAdminHandler* pAH, Screen::Panel* pParent);		
 		    ~Add();
 		    
 		    void setup(const Chain& tableSet);
-		    Screen2::Panel* onConfirm(const ListT<Chain>& valList);			    
-		    Screen2::Panel* onCancel();
+		    Screen::Panel* onConfirm(const ListT<Chain>& valList);			    
+		    Screen::Panel* onCancel();
 		    
 		private:
 		    
@@ -278,15 +278,15 @@ private:
 		    CegoAdminHandler* _pAH;
 		};
 
-		class Conf : public Screen2::Form {
+		class Conf : public Screen::Form {
 		public:
 		    
-		    Conf(CegoAdminHandler* pAH, Screen2::Panel* pParent);		
+		    Conf(CegoAdminHandler* pAH, Screen::Panel* pParent);		
 		    ~Conf();
 		    
 		    void setup(const Chain& tableSet, const Chain& archMode);
-		    Screen2::Panel* onConfirm(const ListT<Chain>& valList);			    
-		    Screen2::Panel* onCancel();
+		    Screen::Panel* onConfirm(const ListT<Chain>& valList);			    
+		    Screen::Panel* onCancel();
 		    
 		private:
 		    
@@ -294,14 +294,14 @@ private:
 		    CegoAdminHandler* _pAH;
 		};
 
-		class Delete : public Screen2::Confirm {		    
+		class Delete : public Screen::Confirm {		    
 		public:
 		    
-		    Delete(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		    Delete(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		    ~Delete();
 		    void setup(const Chain& tableSet, const Chain& al);
-		    Screen2::Panel* onConfirm();		
-		    Screen2::Panel* onCancel();
+		    Screen::Panel* onConfirm();		
+		    Screen::Panel* onCancel();
 		    
 		private:
 
@@ -321,24 +321,24 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 	    
-	    class Backup : public Screen2::Grid {
+	    class Backup : public Screen::Grid {
 	    public:
 
-		Backup(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Backup(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onSelect(int rowNum);
-		Screen2::Panel* onKey(int c, int rowNum);
+		Screen::Panel* onSelect(unsigned rowNum);
+		Screen::Panel* onKey(unsigned c, unsigned rowNum);
 		ListT< ListT<Chain> > getData();
 		void refresh();
 		
 	    private:
 		
-		class Add : public Screen2::Confirm {
+		class Add : public Screen::Confirm {
 		public:
 		
-		    Add(CegoAdminHandler* pAH, Screen2::Panel* pParent);		    
+		    Add(CegoAdminHandler* pAH, Screen::Panel* pParent);		    
 		    void setup(const Chain& tableSet);
-		    Screen2::Panel* onConfirm();
+		    Screen::Panel* onConfirm();
 		    
 		private:
 		   
@@ -346,12 +346,12 @@ private:
 		    CegoAdminHandler* _pAH;
 		};
 
-		class Restore : public Screen2::Form {
+		class Restore : public Screen::Form {
 		public:
 	   
-		    Restore(CegoAdminHandler* pAH, Screen2::Panel* pParent);		    
+		    Restore(CegoAdminHandler* pAH, Screen::Panel* pParent);		    
 		    void setup(const Chain& tableSet, const Chain& buId);
-		    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		    Screen::Panel* onConfirm(const ListT<Chain>& valList);
 		    
 		private:
 		    
@@ -369,24 +369,24 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 	
-	    class FilePanel : public Screen2::Grid {
+	    class FilePanel : public Screen::Grid {
 	    public:
 		
-		FilePanel(CegoAdminHandler* pAH, Screen2::Panel* pParent);	   	    
+		FilePanel(CegoAdminHandler* pAH, Screen::Panel* pParent);	   	    
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onSelect(int rowNum) { return this;  } 
-		Screen2::Panel* onKey(int c, int rowNum);
+		Screen::Panel* onSelect(unsigned rowNum) { return this;  } 
+		Screen::Panel* onKey(unsigned c, unsigned rowNum);
 		ListT< ListT<Chain> > getData() { return _fileTable; };
 		void refresh();
 		
 	    private:
 		
-		class AddFilePanel : public Screen2::Form {
+		class AddFilePanel : public Screen::Form {
 		public:
 		    
-		    AddFilePanel(CegoAdminHandler* pAH, Screen2::Panel* pParent);		    
+		    AddFilePanel(CegoAdminHandler* pAH, Screen::Panel* pParent);		    
 		    void setup(const Chain& tableSet, const Chain& rootPath);
-		    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		    Screen::Panel* onConfirm(const ListT<Chain>& valList);
 		    
 		private:
 
@@ -404,14 +404,14 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 	
- 	    class XPort : public Screen2::Form {
+ 	    class XPort : public Screen::Form {
 	    public:	    
 
-		XPort(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		XPort(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~XPort();
 
 		void setup(const Chain& tableSet, bool isExport);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	 
 	    private:
 
@@ -420,14 +420,14 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class QueryCache : public Screen2::Form {
+	    class QueryCache : public Screen::Form {
 	    public:	    
 
-		QueryCache(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		QueryCache(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~QueryCache();
 
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	 
 	    private:
 
@@ -435,14 +435,14 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class TableCache : public Screen2::Form {
+	    class TableCache : public Screen::Form {
 	    public:	    
 
-		TableCache(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		TableCache(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~TableCache();
 
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	 
 	    private:
 
@@ -450,14 +450,14 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class Parameter : public Screen2::Form {
+	    class Parameter : public Screen::Form {
 	    public:	    
 
-		Parameter(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Parameter(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Parameter();
 
 		void setup(const Chain& tableSet);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	 
 	    private:
 
@@ -465,10 +465,10 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 	    
-	    class InfoPanel : public Screen2::Attribute {
+	    class InfoPanel : public Screen::Attribute {
 	    public:	    
 
-		InfoPanel(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		InfoPanel(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		void setup(const Chain& tableSet);	    
 		void refresh();           
 		bool doRefresh() { return true; };
@@ -479,13 +479,13 @@ private:
 		CegoAdminHandler* _pAH;	    
 	    };
 
-	    class Drop : public Screen2::Confirm {
+	    class Drop : public Screen::Confirm {
 	    public:
 		
-		Drop(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Drop(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Drop();
 		void setup(const Chain& tableSet);	    
-		Screen2::Panel* onConfirm();
+		Screen::Panel* onConfirm();
 		
 	    private:
 
@@ -523,64 +523,64 @@ private:
     // Role Panels //
     /////////////////
 
-    class Role : public Screen2::Grid {
+    class Role : public Screen::Grid {
     public:
 
-	Role(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	Role(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	~Role();
-	Screen2::Panel* onSelect(int selectedRow);
-	Screen2::Panel* onKey(int c, int rowNum);
+	Screen::Panel* onSelect(unsigned selectedRow);
+	Screen::Panel* onKey(unsigned c, unsigned rowNum);
 	ListT< ListT<Chain> > getData();
 	void refresh();
 
     private :
 
-	class Add : public Screen2::Form {
+	class Add : public Screen::Form {
 	public:
 	    
-	    Add(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    Add(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ~Add();
-	    Screen2::Panel* onConfirm(const ListT<Chain>& valList);	
-	    Screen2::Panel* onCancel();
+	    Screen::Panel* onConfirm(const ListT<Chain>& valList);	
+	    Screen::Panel* onCancel();
 	    
 	private:
 
 	    CegoAdminHandler* _pAH;	    
 	};
 		
-	class Action : public Screen2::Select {
+	class Action : public Screen::Select {
 	public:
 	    
-	    Action(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	    Action(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	    ~Action();
 	    void setRole(const Chain& role);	    
-	    Screen2::Panel* onSelect(int selected);
+	    Screen::Panel* onSelect(unsigned selected);
 	    
 	private:
 
-	    class Perm : public Screen2::Grid {
+	    class Perm : public Screen::Grid {
 	    public:
 
-	        Perm(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	        Perm(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Perm();
 		void setup(const Chain& role);
-		Screen2::Panel* onSelect(int rowNum);
-		Screen2::Panel* onKey(int c, int rowNum);
+		Screen::Panel* onSelect(unsigned rowNum);
+		Screen::Panel* onKey(unsigned c, unsigned rowNum);
 		ListT< ListT<Chain> > getData();
 		void refresh();
 		bool doRefresh() { return true; };
 		
 	    private:
 
-		class Edit : public Screen2::Form {		    
+		class Edit : public Screen::Form {		    
 		public:
 		    Edit(CegoAdminHandler* pAH, Panel* pParent);
 		    ~Edit();
 
 		    void clear();
 		    void setup(const Chain& role);
-		    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
-		    Screen2::Panel* onCancel();
+		    Screen::Panel* onConfirm(const ListT<Chain>& valList);
+		    Screen::Panel* onCancel();
 		    
 		private:
 		    
@@ -594,14 +594,14 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class Assign : public Screen2::Form {
+	    class Assign : public Screen::Form {
 	    public:	    
 
-		Assign(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Assign(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Assign();
 
 		void setup(const Chain& role, const ListT<Chain> userList);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 		
 	    private:
 		
@@ -609,15 +609,15 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class Delete : public Screen2::Confirm {
+	    class Delete : public Screen::Confirm {
 		
 	    public:
 
-		Delete(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Delete(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Delete();
 		void setup(const Chain& role);
-		Screen2::Panel* onConfirm();		
-		Screen2::Panel* onCancel();
+		Screen::Panel* onConfirm();		
+		Screen::Panel* onCancel();
 	       	      
 	    private:
 
@@ -646,13 +646,13 @@ private:
     // User Panels //
     /////////////////
     
-    class User : public Screen2::Grid {
+    class User : public Screen::Grid {
     public:
 	
-	User(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+	User(CegoAdminHandler* pAH, Screen::Panel* pParent);
 	~User();
-	Screen2::Panel* onSelect(int selectedRow);
-	Screen2::Panel* onKey(int c, int rowNum);
+	Screen::Panel* onSelect(unsigned selectedRow);
+	Screen::Panel* onKey(unsigned c, unsigned rowNum);
 	ListT< ListT<Chain> > getData();
 	void refresh();
 	bool doRefresh() { return true; };
@@ -661,37 +661,37 @@ private:
 
 	SetT<Chain> roleString2Set(const Chain& roleString);
 	    
-	class Add : public Screen2::Form {
+	class Add : public Screen::Form {
 	public:
 	    
-	    Add(CegoAdminHandler* pAH, Screen2::Panel* pParent);	    
+	    Add(CegoAdminHandler* pAH, Screen::Panel* pParent);	    
 	    ~Add();
-	    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
-	    Screen2::Panel* onCancel();
+	    Screen::Panel* onConfirm(const ListT<Chain>& valList);
+	    Screen::Panel* onCancel();
 	    
 	private:
 	    
 	    CegoAdminHandler* _pAH;	    
 	};
 
-	class Action : public Screen2::Select {
+	class Action : public Screen::Select {
 	public:
 	    
-	    Action(CegoAdminHandler* pAH, Screen2::Panel* pParent);	
+	    Action(CegoAdminHandler* pAH, Screen::Panel* pParent);	
 	    ~Action();	
 	    void setup(const Chain& user, const SetT<Chain>& userRoleSet, bool isTrace);
-	    Screen2::Panel* onSelect(int selected);
+	    Screen::Panel* onSelect(unsigned selected);
 	    
 	private:
 		
-	    class Passwd : public Screen2::Form {
+	    class Passwd : public Screen::Form {
 	    public:
 		
-		Passwd(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Passwd(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Passwd();
 		void setUser(const Chain& user);		
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);		
-		Screen2::Panel* onCancel();
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);		
+		Screen::Panel* onCancel();
 		
 	    private:
 		
@@ -699,14 +699,14 @@ private:
 		CegoAdminHandler* _pAH;		
 	    };
 
-	    class Assign : public Screen2::Form {
+	    class Assign : public Screen::Form {
 	    public:
 		
-		Assign(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Assign(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Assign();
 
 		void setup(const Chain& user, const SetT<Chain> roleSet, bool isAssign);
-		Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+		Screen::Panel* onConfirm(const ListT<Chain>& valList);
 		
 	    private:
 		
@@ -715,13 +715,13 @@ private:
 		CegoAdminHandler* _pAH;
 	    };
 
-	    class Delete : public Screen2::Confirm {		
+	    class Delete : public Screen::Confirm {		
 	    public:
 
-		Delete(CegoAdminHandler* pAH, Screen2::Panel* pParent);
+		Delete(CegoAdminHandler* pAH, Screen::Panel* pParent);
 		~Delete();
 		void setup(const Chain& role);
-		Screen2::Panel* onConfirm();		
+		Screen::Panel* onConfirm();		
 	       	      
 	    private:
 
@@ -750,31 +750,31 @@ private:
     // Setup Panel //
     /////////////////
 
-    class Setup : public Screen2::Select {
+    class Setup : public Screen::Select {
     public:
 
-	Setup(CegoAdmScreen* pScreen, CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);
+	Setup(CegoAdmScreen* pScreen, CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);
 	~Setup();	
-	Screen2::Panel* onSelect(int selected);
+	Screen::Panel* onSelect(unsigned selected);
       
     private:
 	
-	class LogMng : public Screen2::Form {
+	class LogMng : public Screen::Form {
 	public:
 	
-	    LogMng(CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);
-	    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+	    LogMng(CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);
+	    Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	    void setup();
 	private:
 	    
 	    CegoAdminHandler* _pAH;	    
 	};
 	
-	class BackupMng : public Screen2::Form {
+	class BackupMng : public Screen::Form {
 	public:
 	    
-	    BackupMng(CegoAdminHandler* pAH, Screen2::Panel* pParent, const Chain& title);
-	    Screen2::Panel* onConfirm(const ListT<Chain>& valList);
+	    BackupMng(CegoAdminHandler* pAH, Screen::Panel* pParent, const Chain& title);
+	    Screen::Panel* onConfirm(const ListT<Chain>& valList);
 	    void setup();
 	    
 	private:
@@ -782,15 +782,15 @@ private:
 	    CegoAdminHandler* _pAH;	    
 	};
 
-	class Refresh : public Screen2::Select {
+	class Refresh : public Screen::Select {
 	public:
 	    
-	    Refresh(Screen2* pScreen, Screen2::Panel* pParent);
-	    Screen2::Panel* onSelect(int selected);
+	    Refresh(Screen* pScreen, Screen::Panel* pParent);
+	    Screen::Panel* onSelect(unsigned selected);
 	    
 	private:
 	    
-	    Screen2* _pScreen;
+	    Screen* _pScreen;
 	};
 	
 	LogMng* _pLogMng;
