@@ -316,7 +316,7 @@ public:
     ResultType reqEndBackup(const Chain& tableSet, bool keepTicket);
     ResultType reqListBackup(const Chain& tableSet, const Chain& pit);
     ResultType reqRestore(const Chain& tableSet, const Chain& backupId);
-    ResultType reqRecover(const Chain& tableSet, const Chain& pit);
+    ResultType reqRecover(const Chain& tableSet, const Chain& pit, unsigned long long targetlsn);
     ResultType reqSecSwitch(const Chain& tableSet, const Chain& secondary);
 
     ResultType reqDumpObject(const Chain& tableSet, CegoObject::ObjectType type, const Chain& objName);
@@ -386,7 +386,7 @@ public:
     ResultType medEndBackup(const Chain& tableSet, const Chain& msg, bool keepTicket);
     ResultType medListBackup(const Chain& tableSet, const Chain& pit);
     ResultType medRestore(const Chain& tableSet, const Chain& backupId);   
-    ResultType medRecover(const Chain& tableSet, const Chain& pit);
+    ResultType medRecover(const Chain& tableSet, const Chain& pit, unsigned long long lsn);
 
     ResultType medSecSwitch(const Chain& tableSet);
 
