@@ -8,7 +8,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -36,7 +36,6 @@ public:
     enum AlterType { ADD, DROP, MODIFY_COLUMN, MODIFY_DEFAULT, RENAME };
 
     CegoAlterDesc();
-    CegoAlterDesc(Element *pAlterElement);
     CegoAlterDesc(AlterType type, const CegoField& f);
     CegoAlterDesc(AlterType type, const Chain& attrName);
     CegoAlterDesc(const Chain& oldAttrName, const Chain& newAttrName);
@@ -56,9 +55,6 @@ public:
     Chain toChain() const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
-    Element* toElement() const;
-    void fromElement(Element *pAlterElement);
-
     friend ostream& operator << (ostream& s, const CegoAlterDesc& a);
     
 private:
