@@ -54,8 +54,8 @@ public:
 
     CompMode getCompMode() const;
 
-    int getPos() const;
-    void setPos(int pos);
+    unsigned getPos() const;
+    void setPos(unsigned pos);
     
     void setTableName(const Chain& tableName);
     const Chain& getTableName() const;
@@ -82,7 +82,7 @@ public:
     void setParentSetup() { _isParentSetup = true; }
 	
     bool setup(const ListT<CegoField>& fl);
-    bool setup(ListT<CegoField>** pJoinBuf, int offset);
+    bool setup(ListT<CegoField>** pJoinBuf, unsigned offset);
 
     bool isNullComp() const;
     
@@ -102,7 +102,7 @@ public:
       
 private:
 
-    int _pos;
+    unsigned _pos;
     Chain _tableName;
     Chain _attrName;
     CegoComparison _comp;
@@ -118,10 +118,10 @@ private:
     bool _isSetup;
     bool _isSetup2;
 
-    int _xpos;
-    int _ypos;
-    int _xpos2;
-    int _ypos2;
+    unsigned _xpos;
+    unsigned _ypos;
+    unsigned _xpos2;
+    unsigned _ypos2;
 
     bool _posSetup;
     bool _isParentSetup;
