@@ -65,12 +65,12 @@ void CegoAttrCond::add(const CegoAttrComp& attrComp)
     }
 }
 
-int CegoAttrCond::numComp() const
+unsigned CegoAttrCond::numComp() const
 {
     return _attrCompSet.Size();
 }
 
-int CegoAttrCond::getStrength() const
+unsigned CegoAttrCond::getStrength() const
 {
     CegoAttrComp *pAC = _attrCompSet.First();
     if ( pAC )
@@ -153,7 +153,7 @@ CegoAttrCond CegoAttrCond::getIndexCond(const ListT<CegoField>& fl) const
 
     ac.setAnd(_isAnd);
     
-    int pos = 0;
+    unsigned pos = 0;
     CegoField *pF = fl.First();
  
     while ( pF  )
@@ -190,7 +190,7 @@ bool CegoAttrCond::setup(const ListT<CegoField>& fl)
     return true;
 }
 
-bool CegoAttrCond::setup(ListT<CegoField>** pJoinBuf, int offset)
+bool CegoAttrCond::setup(ListT<CegoField>** pJoinBuf, unsigned offset)
 {
     CegoAttrComp *pAC = _attrCompSet.First();
     while ( pAC )
@@ -208,7 +208,7 @@ bool CegoAttrCond::setup(ListT<CegoField>** pJoinBuf, int offset)
     return true;
 }
 
-bool CegoAttrCond::setup(ListT<CegoField>** pParentJoinBuf, int parentOffset, ListT<CegoField>** pJoinBuf, int offset)
+bool CegoAttrCond::setup(ListT<CegoField>** pParentJoinBuf, unsigned parentOffset, ListT<CegoField>** pJoinBuf, unsigned offset)
 {
     CegoAttrComp *pAC = _attrCompSet.First();
     while ( pAC )
@@ -404,7 +404,7 @@ CegoExpr* CegoAttrCond::getExpressionForAlias(const ListT<CegoExpr*>& exprList,
 
 CegoAttrCond::IndexMatch CegoAttrCond::checkIndex(const ListT<CegoField>& schema) const
 {
-    int numFound=0;
+    unsigned numFound=0;
 
     bool hasLeak=false;
     CegoField *pF = schema.First();
@@ -438,22 +438,15 @@ CegoAttrCond::IndexMatch CegoAttrCond::checkIndex(const ListT<CegoField>& schema
 	pF = schema.Next();
     }
 
-    if ( numFound == (int)_attrCompSet.Size() )
+    if ( numFound == (unsigned)_attrCompSet.Size() )
 	return FULL;
 
-    if ( numFound < (int)_attrCompSet.Size() && numFound > 0 )
+    if ( numFound < (unsigned)_attrCompSet.Size() && numFound > 0 )
 	return PART;
     
     return INAPP;
 }
 
-/*
-void CegoAttrCond::setIdxSchema(const ListT<CegoField>& schema)
-{
-    _idxSchema = schema;
-}
-*/
-
 void CegoAttrCond::setPrimaryComparison(CegoComparison comp)
 {
     CegoAttrComp* pAC = _attrCompSet.First();
