@@ -34,7 +34,7 @@ CegoCaseCond::CegoCaseCond()
     _elseExpr = 0;
 }
 
-CegoCaseCond::CegoCaseCond(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoCaseCond::CegoCaseCond(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _elseExpr = 0;
     decode(buf, pGTM, pBlock, tabSetId);
@@ -78,7 +78,7 @@ void CegoCaseCond::cleanUp()
 	_elseExpr->cleanUp();
 }
 
-void CegoCaseCond::setTabSetId(int tabSetId)
+void CegoCaseCond::setTabSetId(unsigned tabSetId)
 {
     CegoPredicate **pPredDesc = _predList.First();
     while ( pPredDesc )
@@ -145,9 +145,9 @@ ListT<CegoAttrDesc*> CegoCaseCond::getAttrRefList() const
     return attrList;
 }
 
-int CegoCaseCond::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoCaseCond::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     CegoPredicate **pPredDesc = _predList.First();
     while ( pPredDesc )
@@ -350,7 +350,7 @@ Chain CegoCaseCond::getId(CegoProcBlock *pBlock) const
     return s;
 }
 
-Chain CegoCaseCond::toChain(int defTabSetId) const
+Chain CegoCaseCond::toChain(unsigned defTabSetId) const
 {
     Chain s;
     s = Chain("case");
@@ -378,9 +378,9 @@ void CegoCaseCond::encode(char *buf, CegoProcBlock *pBlock)
 {
     char* pE = (char*)buf;
 
-    int numPred = _predList.Size();
-    memcpy( pE, &numPred, sizeof(int));
-    pE = pE + sizeof(int);
+    unsigned numPred = _predList.Size();
+    memcpy( pE, &numPred, sizeof(unsigned));
+    pE = pE + sizeof(unsigned);
 
     CegoPredicate **pPredDesc = _predList.First();
     CegoExpr **pExpr = _exprList.First();
@@ -398,15 +398,15 @@ void CegoCaseCond::encode(char *buf, CegoProcBlock *pBlock)
     _elseExpr->encode(pE, pBlock);    
 }
 
-void CegoCaseCond::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoCaseCond::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
-    int numPred;
-    memcpy( &numPred, pE, sizeof(int));
-    pE = pE + sizeof(int);
+    unsigned numPred;
+    memcpy( &numPred, pE, sizeof(unsigned));
+    pE = pE + sizeof(unsigned);
 
-    int i=0;
+    unsigned i=0;
     while ( i < numPred )
     {
 	CegoPredicate *pPred = new CegoPredicate(pE, pGTM, pBlock, tabSetId);
@@ -422,9 +422,9 @@ void CegoCaseCond::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBloc
     _elseExpr = new CegoExpr(pE, pGTM, pBlock, tabSetId);
 }
 
-int CegoCaseCond::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoCaseCond::getEncodingLength(CegoProcBlock *pBlock) const
 {
-    int len = sizeof(int);
+    unsigned len = sizeof(unsigned);
     
     CegoPredicate **pPredDesc = _predList.First();
     CegoExpr **pExpr = _exprList.First();
