@@ -37,12 +37,12 @@ CegoCheckObject::CegoCheckObject(const CegoCheckObject& co) : CegoDecodableObjec
     _pPredDesc = co._pPredDesc->clone();
 }
 
-CegoCheckObject::CegoCheckObject(ObjectType type, const Chain& objName, int tabSetId) : CegoDecodableObject(type, objName, tabSetId)
+CegoCheckObject::CegoCheckObject(ObjectType type, const Chain& objName, unsigned tabSetId) : CegoDecodableObject(type, objName, tabSetId)
 {
     _pPredDesc = 0;
 }
 
-CegoCheckObject::CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc) : CegoDecodableObject(CegoObject::CHECK, checkName, tabSetId)
+CegoCheckObject::CegoCheckObject(unsigned tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc) : CegoDecodableObject(CegoObject::CHECK, checkName, tabSetId)
 {
     _pPredDesc = pPredDesc;
     _tabName = tabName;
@@ -76,9 +76,9 @@ CegoPredicate* CegoCheckObject::getPredDesc()
     return _pPredDesc;
 }
 
-int CegoCheckObject::getEntrySize() const
+unsigned CegoCheckObject::getEntrySize() const
 {
-    int entrySize = CegoObject::getBaseSize();
+    unsigned entrySize = CegoObject::getBaseSize();
 
     entrySize += 1; // object tabname size
     entrySize += _tabName.length();
@@ -91,7 +91,7 @@ void CegoCheckObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
 
     CegoObject::encodeBase(bufPtr, entrySize);
     bufPtr += CegoObject::getBaseSize();
@@ -112,7 +112,7 @@ void CegoCheckObject::decode(char *buf)
 {
     char* bufPtr = buf;
 
-    int size;
+    unsigned size;
 
     CegoObject::decodeBase(bufPtr, size);
     bufPtr += CegoObject::getBaseSize();
@@ -140,7 +140,7 @@ bool CegoCheckObject::operator == ( const CegoCheckObject& co)
     return CegoObject::operator==(co);
 }
 
-Chain CegoCheckObject::toChain(int defTabSetId) const
+Chain CegoCheckObject::toChain(unsigned defTabSetId) const
 {
     Chain s;
     s = CegoObject::toChain();
