@@ -36,8 +36,8 @@ class CegoCheckObject : public CegoDecodableObject {
 
     CegoCheckObject();
     CegoCheckObject(const CegoCheckObject& co);
-    CegoCheckObject(ObjectType type,  const Chain& objName, int tabSetId = 0);
-    CegoCheckObject(int tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc);	
+    CegoCheckObject(ObjectType type,  const Chain& objName, unsigned tabSetId = 0);
+    CegoCheckObject(unsigned tabSetId, const Chain& checkName, const Chain& tabName, CegoPredicate *pPredDesc);	
     ~CegoCheckObject();
 
     void setTabName(const Chain& name);
@@ -46,7 +46,7 @@ class CegoCheckObject : public CegoDecodableObject {
     void setPredDesc(CegoPredicate *pPredDesc);   
     CegoPredicate* getPredDesc();
 
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
 
     void encode(char *buf) const;
     void decode(char *buf);
@@ -54,7 +54,7 @@ class CegoCheckObject : public CegoDecodableObject {
     CegoCheckObject& operator = ( const CegoCheckObject& oe);
     bool operator == ( const CegoCheckObject& oe);
     
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
 
     Chain getInfo() const;
 
