@@ -30,7 +30,7 @@ class CegoCheckpointDump {
     
 public:
 
-    CegoCheckpointDump(Chain& tableSet, Chain& tsRoot, int pageSize);
+    CegoCheckpointDump(Chain& tableSet, Chain& tsRoot, unsigned pageSize);
     
     void startWrite();
     void dumpPage(PageIdType pageId, unsigned fixStat, char* pageData);
@@ -50,7 +50,7 @@ private:
 
     Chain _tableSet;
     Chain _tsRoot;
-    int _pageSize;
+    unsigned _pageSize;
     
     File* _pDumpFile;
 };
