@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2013 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -32,14 +32,14 @@ enum CegoDataType
   FLOAT_TYPE,
   DOUBLE_TYPE,
   DECIMAL_TYPE,
-  FIXED_TYPE,
   SMALLINT_TYPE,
   TINYINT_TYPE,
   BLOB_TYPE,
   CLOB_TYPE,
-  NULL_TYPE
+  NULL_TYPE,
+  // just internal use
+  PAGEID_TYPE
 };
-
 #endif
 
 
