@@ -31,7 +31,7 @@ CegoDecodableObject::CegoDecodableObject(const CegoDecodableObject& co) : CegoOb
     _isLocal = true;
 }
 
-CegoDecodableObject::CegoDecodableObject(CegoObject::ObjectType type, const Chain& objName, int tabSetId) : CegoObject(type, objName, tabSetId)
+CegoDecodableObject::CegoDecodableObject(CegoObject::ObjectType type, const Chain& objName, unsigned tabSetId) : CegoObject(type, objName, tabSetId)
 {
     _isLocal = true;
 }
