@@ -34,10 +34,10 @@ public:
         
     CegoDecodableObject();
     CegoDecodableObject(const CegoDecodableObject& co);
-    CegoDecodableObject(CegoObject::ObjectType type, const Chain& objName, int tabSetId);
+    CegoDecodableObject(CegoObject::ObjectType type, const Chain& objName, unsigned tabSetId);
     virtual ~CegoDecodableObject();
 
-    virtual int getEntrySize() const = 0;
+    virtual unsigned getEntrySize() const = 0;
     virtual void encode(char *buf) const = 0;
     virtual void decode(char *buf) = 0;
     
