@@ -117,7 +117,7 @@ void CegoDistDbHandler::getCreateTableArg(Chain& tableSet, Chain& tableName, Lis
 		Chain colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR);
 		
 		CegoTypeConverter tc;
-		CegoField f(CegoField(tableName, tableName, colName, tc.getTypeId(colType), colSize.asInteger()));	    
+		CegoField f(CegoField(tableName, tableName, colName, tc.getTypeId(colType), colSize.asUnsigned()));	    
 		fl.Insert(f);
 		
 		pCol = colList.Next();
@@ -151,7 +151,7 @@ void CegoDistDbHandler::getCreateViewArg(Chain& tableSet, Chain& viewName, ListT
 		Chain colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR);
 		
 		CegoTypeConverter tc;
-		CegoField f(CegoField(viewName, viewName, colName, tc.getTypeId(colType), colSize.asInteger()));	    
+		CegoField f(CegoField(viewName, viewName, colName, tc.getTypeId(colType), colSize.asUnsigned()));	    
 		fl.Insert(f);
 		pCol = colList.Next();
 	    }
@@ -298,14 +298,14 @@ void CegoDistDbHandler::getCreateIndexArg(Chain& tableSet, Chain& indexName, Cha
     }
 }
 
-void CegoDistDbHandler::getObjectInfoArg(int& tabSetId, Chain& tableName, CegoObject::ObjectType& type)
+void CegoDistDbHandler::getObjectInfoArg(unsigned& tabSetId, Chain& tableName, CegoObject::ObjectType& type)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
-	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asInteger();
+	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asUnsigned();
 	    tableName = pRoot->getAttributeValue(XML_OBJNAME_ATTR);
 	    
 	    CegoTypeConverter tc;
@@ -318,14 +318,14 @@ void CegoDistDbHandler::getObjectInfoArg(int& tabSetId, Chain& tableName, CegoOb
     }
 }
 
-void CegoDistDbHandler::getGetTableArg(int& tabSetId, Chain& tableName, CegoObject::ObjectType& type)
+void CegoDistDbHandler::getGetTableArg(unsigned& tabSetId, Chain& tableName, CegoObject::ObjectType& type)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
-	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asInteger();
+	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asUnsigned();
 	    tableName = pRoot->getAttributeValue(XML_TABLENAME_ATTR);
 	    
 	    CegoTypeConverter tc;
@@ -380,14 +380,14 @@ void CegoDistDbHandler::getReorgArg(Chain& tableSet, Chain& objName, CegoObject:
     }
 }
 
-void CegoDistDbHandler::getGetObjectListArg(int& tabSetId, CegoObject::ObjectType& type)
+void CegoDistDbHandler::getGetObjectListArg(unsigned& tabSetId, CegoObject::ObjectType& type)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
-	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asInteger();
+	    tabSetId = pRoot->getAttributeValue(XML_TSID_ATTR).asUnsigned();
 	    
 	    CegoTypeConverter tc;
 	    type = tc.getObjectTypeId(pRoot->getAttributeValue(XML_TABLETYPE_ATTR));	    
@@ -416,7 +416,7 @@ void CegoDistDbHandler::getGetObjectByTableListArg(Chain& tableSet, Chain& table
     }
 }
     
-void CegoDistDbHandler::getSyncArg(Chain& tableSet, Chain& escCmd, int& timeout)
+void CegoDistDbHandler::getSyncArg(Chain& tableSet, Chain& escCmd, unsigned& timeout)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -425,7 +425,7 @@ void CegoDistDbHandler::getSyncArg(Chain& tableSet, Chain& escCmd, int& timeout)
 	{
 	    tableSet = pRoot->getAttributeValue(XML_TABLESET_ATTR);
 	    escCmd = pRoot->getAttributeValue(XML_ESCCMD_ATTR);
-	    timeout = pRoot->getAttributeValue(XML_TIMEOUT_ATTR).asInteger();
+	    timeout = pRoot->getAttributeValue(XML_TIMEOUT_ATTR).asUnsigned();
 	}
     }
     else
@@ -667,7 +667,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateIndexOp(const Chain& t
     }
 }
 
-CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateFKeyOp(int tabSetId, const Chain& fkey, 
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateFKeyOp(unsigned tabSetId, const Chain& fkey, 
 								 const Chain& tableName, 
 								 const ListT<CegoField>& keyList, 
 								 const Chain& refTable, 
@@ -710,7 +710,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateFKeyOp(int tabSetId, c
     }
 }
 
-CegoDistDbHandler::ResultType CegoDistDbHandler::reqTableDataOp(int tabSetId, const Chain& tableName, CegoObject::ObjectType type)
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqTableDataOp(unsigned tabSetId, const Chain& tableName, CegoObject::ObjectType type)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -729,7 +729,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqTableDataOp(int tabSetId, co
     }
 }
 
-CegoDistDbHandler::ResultType CegoDistDbHandler::reqGetObjectListOp(int tabSetId, CegoObject::ObjectType type)
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqGetObjectListOp(unsigned tabSetId, CegoObject::ObjectType type)
 {
     if ( _protType == CegoDbHandler::XML )
     {
@@ -783,7 +783,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqRenameOp(const Chain& tableS
     }
 }
 
-CegoDistDbHandler::ResultType CegoDistDbHandler::reqSyncOp(const Chain& tableSet, const Chain& escCmd, int timeout)
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqSyncOp(const Chain& tableSet, const Chain& escCmd, unsigned timeout)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -861,7 +861,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateCheckOp(const Chain& t
 }
 */
 
-CegoDistDbHandler::ResultType CegoDistDbHandler::reqObjectInfoOp(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqObjectInfoOp(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -1130,7 +1130,7 @@ void CegoDistDbHandler::sendObjByTableList(const ListT<CegoTableObject>& idxList
     throw Exception(EXLOC, Chain("No more supported"));
 }
 
-void CegoDistDbHandler::sendTID(int tid)
+void CegoDistDbHandler::sendTID(unsigned tid)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -1163,7 +1163,7 @@ void CegoDistDbHandler::sendTID(int tid)
     }
 }
 
-void CegoDistDbHandler::sendPageCount(int pageCount)
+void CegoDistDbHandler::sendPageCount(unsigned pageCount)
 {
     if ( _protType == CegoDbHandler::XML )
     {	
@@ -1292,14 +1292,14 @@ void CegoDistDbHandler::getObjectByTableList(ListT<CegoTableObject>& idxList,
     throw Exception(EXLOC, Chain("No more supported"));
 }
 
-void CegoDistDbHandler::getPageCount(int& pageCount)
+void CegoDistDbHandler::getPageCount(unsigned& pageCount)
 {
     if ( _protType == CegoDbHandler::XML )
     {
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
-	    pageCount = pRoot->getAttributeValue(XML_PAGECOUNT_ATTR).asInteger();	    
+	    pageCount = pRoot->getAttributeValue(XML_PAGECOUNT_ATTR).asUnsigned();	    
 	}
     }
     else
