@@ -278,7 +278,10 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
     
     Chain dbHost;
     _pDBMng->getDBHost(dbHost);
-    
+
+    // we assume recovery mode during first startup phase
+    _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
+	        
     if ( secondary != dbHost )
     {
 	unsigned logPort;
@@ -295,45 +298,35 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
     }
     else
     {
-	// we have to set tableset state for recovery
-	_pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
 
         // set active log file
         _pDBMng->setActiveLogFile(tableSet);
 
         // get max written lsn
-        long maxlsn = _pDBMng->getMaxLSN(tabSetId);
-
-        _pDBMng->log(_modId, Logger::NOTICE, Chain("Setting lsn to ") + Chain(maxlsn));
-        _pDBMng->setCurrentLSN(tabSetId, maxlsn);
+        unsigned long long maxLogLSN = _pDBMng->getMaxLSN(tabSetId);
 
         registerObjects(tableSet);
 
         // get checkpoint lsn
         long cplsn = _pDBMng->getCommittedLSN(tableSet);
 
-	if ( cplsn == maxlsn || ( cplsn == 0 && maxlsn == 0 ) )
+	_pDBMng->setCurrentLSN(tabSetId, cplsn);
+	
+	if ( cplsn == maxLogLSN ||  maxLogLSN == 0  )
 	{
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Tableset ") + tableSet + Chain(" in sync at lsn=") + Chain(cplsn) + Chain(", no recovery required"));
 	    finishOpenTransaction(tabSetId);
 	}
-	else if ( cplsn < maxlsn )
-	{	    
-	    long minlsn = _pDBMng->getMinLSN(tabSetId);
+	else if ( cplsn < maxLogLSN )
+	{
 	    
-	    if ( cplsn + 1 < minlsn )
-	    {
-		throw Exception(EXLOC, Chain("Checkpoint lsn=") + Chain(cplsn) + Chain(" is too small ( minlsn=") + Chain(minlsn) + Chain(")")); 
-	    }
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Tableset ") + tableSet + Chain(" not in sync, recovery required ( Commited lsn=") + Chain(cplsn) + Chain(")"));
-
-	    _pDBMng->setCurrentLSN(tabSetId, cplsn);
 	    
 	    unsigned long long lsn;
 	    long long ts = 0;
 
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Starting recovery ... "));    
-
+	    	    	
 	    setIgnoreInvalid(true);
 
 	    try
@@ -342,7 +335,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 		// _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
 		
 		CegoRecoveryManager recoveryMng(this, CegoRecoveryManager::LOCAL);
-		recoveryMng.recoverCurrentTransactionLog(tabSetId, 0, lsn, ts);
+		recoveryMng.recoverCurrentTransactionLog(tabSetId, 0, 0, lsn, ts);
 
 		// increase lsn to next
 		_pDBMng->setCurrentLSN(tabSetId, lsn);
@@ -355,8 +348,6 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 		
 		setIgnoreInvalid(false);
 		
-		// set lsn to last lsn in log
-		_pDBMng->writeCheckPoint(tableSet, true, false, _pLockHandle);
 	    }
 	    catch ( Exception e)
 	    {
@@ -366,7 +357,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	}
 	else
 	{
-	    throw Exception(EXLOC, "Checkpoint lsn is too high ( maxlsn = " + Chain(maxlsn) + ", lsn=" + Chain(cplsn) + Chain(")")); 
+	    throw Exception(EXLOC, "Checkpoint lsn is too high ( max log lsn = " + Chain(maxLogLSN) + ", lsn=" + Chain(cplsn) + Chain(")")); 
 	}
 
 	// do autocorrect here
@@ -398,17 +389,6 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	    resetTemp(tableSet);
 	}
 	
-	// setting current lsn, 
-	// since the cleanTableSet procedure might fix buffers and might write a checkpoint,
-	// this must be done BEFORE the cleanIt option is performced.
-	// Fixed with version 2.47.11
-
-	// Fix in version 2.47.14 : the current lsn has to be setup before registerObjects
-	// since also this method might trigger checkpoints
-	
-	// _pDBMng->log(_modId, Logger::NOTICE, Chain("Setting lsn to ") + Chain(maxlsn));
-	// _pDBMng->setCurrentLSN(tabSetId, maxlsn);
-
 	if ( cleanIt )
 	{
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Cleaning tableset ") + tableSet + Chain(" ..."));
@@ -419,13 +399,19 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	// now starting log
 	_pDBMng->log(_modId, Logger::NOTICE, Chain("Starting log for tableset ") + tableSet + Chain(" ..."));
 	_pDBMng->startLog(tabSetId);
+
     }
     
+    _pDBMng->setTableSetRunState(tableSet, XML_ONLINE_VALUE); 
+    _pDBMng->setTableSetSyncState(tableSet, XML_SYNCHED_VALUE);
+        
+    // finally, we write a checkpoint with log switch ( must be done after startLog )
+    _pDBMng->writeCheckPoint(tableSet, true, false, _pLockHandle);
+    
     _pDBMng->allocateTableCache(tableSet);
     _pDBMng->allocateQueryCache(tableSet);
 
-    _pDBMng->setTableSetRunState(tableSet, XML_ONLINE_VALUE); 
-    _pDBMng->setTableSetSyncState(tableSet, XML_SYNCHED_VALUE); 
+    
 }
 
 bool CegoDistManager::distObjectExists(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType objType)
