@@ -36,7 +36,7 @@ class CegoExpOutStream : public XMLOutStream {
     
 public:
     
-    CegoExpOutStream(int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoDistManager* pGTM, CegoAdminHandler* pAH = 0);
+    CegoExpOutStream(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoDistManager* pGTM, CegoAdminHandler* pAH = 0);
     ~CegoExpOutStream();
 
     unsigned long long numExported() const;
@@ -54,6 +54,6 @@ private:
     ListT<CegoField> _schema;
     Chain _tableName;
     unsigned long long _rowCount;
-    int _tabSetId;
+    unsigned _tabSetId;
 };
 #endif
