@@ -38,11 +38,11 @@ CegoKeyObject::CegoKeyObject(const CegoKeyObject& ko)  : CegoDecodableObject(ko)
     _tabName = ko._tabName;
 }
 
-CegoKeyObject::CegoKeyObject(ObjectType type, const Chain& objName, int tabSetId) : CegoDecodableObject(type, objName, tabSetId)
+CegoKeyObject::CegoKeyObject(ObjectType type, const Chain& objName, unsigned tabSetId) : CegoDecodableObject(type, objName, tabSetId)
 {
 }
 
-CegoKeyObject::CegoKeyObject(int tabSetId, const Chain& fkey, const Chain& tabName, const ListT<CegoField>& keySchema, const Chain& refTable, const ListT<CegoField>& refSchema) : CegoDecodableObject(CegoObject::FKEY, fkey, tabSetId)
+CegoKeyObject::CegoKeyObject(unsigned tabSetId, const Chain& fkey, const Chain& tabName, const ListT<CegoField>& keySchema, const Chain& refTable, const ListT<CegoField>& refSchema) : CegoDecodableObject(CegoObject::FKEY, fkey, tabSetId)
 {
     _keySchema = keySchema;
     _refTable = refTable;
@@ -94,9 +94,9 @@ const ListT<CegoField>& CegoKeyObject::getRefSchema() const
     return _refSchema;
 }
 
-int CegoKeyObject::getEntrySize() const
+unsigned CegoKeyObject::getEntrySize() const
 {
-    int entrySize = CegoObject::getBaseSize();
+    unsigned entrySize = CegoObject::getBaseSize();
 
     entrySize += 1; // object tabname size
     entrySize += _tabName.length();
@@ -127,7 +127,7 @@ void CegoKeyObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
 
     CegoObject::encodeBase(bufPtr, entrySize);
     bufPtr += CegoObject::getBaseSize();
@@ -182,7 +182,7 @@ void CegoKeyObject::decode(char *buf)
 {
     char* bufPtr = buf;
 
-    int size;
+    unsigned size;
 
     CegoObject::decodeBase(bufPtr, size);
     bufPtr += CegoObject::getBaseSize();
@@ -195,7 +195,7 @@ void CegoKeyObject::decode(char *buf)
     memcpy (&c, bufPtr , 1);
     bufPtr++;
     
-    int i=0;
+    unsigned i=0;
     while ( i < c )
     {
 	Chain attrName = Chain(bufPtr);
