@@ -95,7 +95,9 @@ Chain CegoLogManager::getArchiveLogName(const Chain& tableSet, unsigned long lon
 void CegoLogManager::setLogFile(unsigned tabSetId, const Chain& logFile, bool readOnly)
 {
     if (_pLog[tabSetId])
-    {
+    {	
+	if ( __fsyncOn )
+	    _pLog[tabSetId]->flush();
 	_pLog[tabSetId]->close();
 	delete _pLog[tabSetId];
     }
@@ -235,7 +237,13 @@ CegoLogManager::LogResult CegoLogManager::logAction(unsigned tabSetId, CegoLogRe
     
     // cout << "Logging " <<  _lsn[tabSetId] << " " << logRec << endl;
 
-    if ( logRec.getLSN() == 0 )
+    if ( logRec.getLSN() == 0
+	 && logRec.getAction() != CegoLogRecord::LOGREC_SYNC )
+
+	/*
+	 && logRec.getAction() != CegoLogRecord::LOGREC_BUFBM
+	 && logRec.getAction() != CegoLogRecord::LOGREC_BUPAGE
+	 && logRec.getAction() != CegoLogRecord::LOGREC_BUFIN ) */
     {
 	logRec.setLSN(nextLSN(tabSetId));
     }
@@ -297,10 +305,9 @@ CegoLogManager::LogResult CegoLogManager::logAction(unsigned tabSetId, CegoLogRe
 	_pLog[tabSetId]->writeByte((char*)&_logOffset[tabSetId], sizeof(unsigned));
 	_pLog[tabSetId]->seek(_logOffset[tabSetId]);
 
-	if ( flushLog )
+	if ( ( flushLog || isFull ) && __fsyncOn )
 	{
-	    if ( __fsyncOn )
-		_pLog[tabSetId]->flush();
+	    _pLog[tabSetId]->flush();
 	}
     }
     
