@@ -53,10 +53,15 @@ public:
     bool isTerminated();
     void getLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
 
+
+    static void shiftActive(CegoDatabaseManager *pDBMng, const Chain& tableSet);
+    
 private:
 
-    void copyLog(const Chain& tableSet, const Chain& logFileName, const Chain& archLogPath);
     void shiftRedoLogs();
+
+    static void copyLog(CegoDatabaseManager* pDBMng, const Chain& tableSet, const Chain& logFileName, const Chain& archLogPath);
+
     void lockQueue();
     void unlockQueue();
 	
