@@ -23,11 +23,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-// improved bsd random functions still not supported for mingw
-#ifdef HAVE_MINGW
-#define srandom srand
-#endif
-
 // LFC INCLUDES
 #include <lfcbase/Sleeper.h>
 #include <lfcbase/Process.h>
@@ -86,7 +81,9 @@
   Query Cache Mode:   cego --mode=querycache --tableset=<string> [ --enable ]\n\
                          [ --maxsize=<int> ] [ --maxentry=<int> ] [ --hashrange=<int> ] [ --threshold=<int> ] --dbxml=<filename>\n\
 \n\
-  Export Mode:        cego --mode={xmlexport|binexport|plainexport} --expfile=<filename>\n\
+  Log Shitt Mode:     cego --mode=shiftactive --tableset=<string>  --dbxml=<filename>\n\
+\n\
+  Export Mode:        cego --mode={xmlexport|binexport|plainexport} --expfile=<filename>\n \
                            --tableset=<string> --dbxml=<filename> --user=<string>/<string>\n\
 \n\
   Import Mode:        cego --mode={xmlimport|binimport|plainimport} --impfile=<filename>\n\
@@ -107,11 +104,7 @@
 #define SYSLOGPROGNAME "cego"
 #define DEFAULTLOGFILE "cego.log"
 #define DEFAULTSYSLOG "yes"
-#ifdef HAVE_MINGW
-#define DEFAULTLOCKFILE "c:/windows/temp/cego.lock"
-#else
 #define DEFAULTLOCKFILE "/tmp/cego.lock"
-#endif
 #define DEFAULTPROTOCOL "fastserial"
 #define DEFAULTPOOLSIZE "3x1000"
 #define DEFAULTDBTHREADNUM 10
@@ -184,7 +177,8 @@ int runBatch(GetLongOpt& longOpt);
 int runDaemon(GetLongOpt& longOpt);
 bool getPoolInfo(const Chain& poolSize, unsigned& numSeg, unsigned& segSize);
 int setQueryCache(GetLongOpt& longOpt);
-
+int shiftActive(GetLongOpt& longOpt);
+    
 int main(int argc, char **argv)
 {	
     GetLongOpt longOpt(argc, argv);
@@ -391,10 +385,6 @@ int main(int argc, char **argv)
     }
     else if ( mode == Chain("daemon") )
     {
-#ifdef HAVE_MINGW
-	cerr << "Daemon mode for windows not supported" << endl;
-	exit(1);	
-#else	 
 	pid_t pid;
 	
 	pid = fork();  
@@ -416,7 +406,6 @@ int main(int argc, char **argv)
 	}
       
 	exitCode = runDaemon(longOpt);
-#endif
     }
     else if ( mode == Chain("server") )
     {
@@ -427,6 +416,10 @@ int main(int argc, char **argv)
     {
 	exitCode = setQueryCache(longOpt);
     }
+    else if ( mode == Chain("shiftactive") )
+    {
+	exitCode = shiftActive(longOpt);
+    }
 
     else
     {
@@ -2021,6 +2014,61 @@ int setQueryCache(GetLongOpt& longOpt)
     return exitCode;
 }
 
+int shiftActive(GetLongOpt& longOpt)
+{
+    int exitCode = 0;
+
+    CegoDatabaseManager* pDBMng = 0;
+
+    try
+    {	
+
+	Chain syslog = longOpt.getOptValue("syslog");
+	Chain logFile = longOpt.getOptValue("logfile");
+	Chain lockFile = longOpt.getOptValue("lockfile");
+	Chain lockExpire = longOpt.getOptValue("lockexpire");
+	Chain dbXML = longOpt.getOptValue("dbxml");
+	Chain tableSet = longOpt.getOptValue("tableset");
+	
+	if ( dbXML.length() == 0  || dbXML == Chain() )
+	{
+	    throw Exception(EXLOC, "No dbxml set");
+	}
+	if ( tableSet.length() == 0 || tableSet == Chain() )
+	{
+	    throw Exception(EXLOC, "No tableSet set");
+	}
+
+	Chain progName = SYSLOGPROGNAME;
+	if ( syslog == Chain("no") )
+	    progName=Chain();
+	
+	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
+	       
+	pDBMng->xml2Doc();
+	pDBMng->configureLogger();
+
+	CegoLogThreadPool::shiftActive(pDBMng, tableSet);
+		       	
+	pDBMng->doc2Xml();
+	
+	delete pDBMng;	
+    }
+    catch (Exception e)
+    {
+	if ( pDBMng ) 
+	    delete pDBMng;
+
+	Chain msg;
+	e.pop(msg);
+	cerr << msg << endl;
+	exitCode = 1;
+    }
+    
+    return exitCode;
+}
+
+
 bool getPoolInfo(const Chain& poolSize, unsigned& numSeg, unsigned& segSize)
 {
     Tokenizer tok(poolSize, "xX");
