@@ -40,7 +40,7 @@ public:
     
     enum CompMode { EXPRONLY, EXPRCOMP, EXISTSCOMP, ISLIKE, ISNOTLIKE, ISNCLIKE, ISNOTNCLIKE, IN, NOTIN, INSUB, NOTINSUB, NULLCOMP, NOTNULLCOMP, NOTPRED, BETWEEN, CONDITION };
         
-    CegoPredicate(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoPredicate(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoPredicate(const CegoPredicate& p);
     CegoPredicate(CegoExpr *pExpr1, CegoExpr *pExpr2, const CegoComparison& comp);
     CegoPredicate(CegoExpr *pExpr1, CegoExpr *pExpr2, CegoExpr *pExpr3);
@@ -55,7 +55,7 @@ public:
     
     ~CegoPredicate();
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     void getPlanList(ListT<Element*>& planList);
 
     CegoExpr* getExpr1();
@@ -89,27 +89,27 @@ public:
     SetT<Chain> getTableRefSet() const;
     ListT<CegoAttrDesc*> getAttrRefList() const;
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) const;
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
     ListT<CegoAggregation*> getAggregationList();
     
     void setAggregationValue(ListT<CegoField>& jfl);
 
     bool eval(ListT<CegoField>** pParentJoinBuf,
-	      int parentJoinBufPos,
+	      unsigned parentJoinBufPos,
 	      ListT<CegoField>** pJoinBuf,
-	      int pos,
+	      unsigned pos,
 	      CegoProcBlock *pBlock);
 
 
     
     CegoPredicate* clone(bool isAttrRef = false);
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm);
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     CegoPredicate& operator = ( const CegoPredicate& p);
     friend ostream& operator << (ostream& s, const CegoPredicate& p);
