@@ -64,7 +64,7 @@ CegoQueryCache::QueryCacheEntry::QueryCacheEntry(const Chain& queryId, const Set
     {
 	CegoFieldValue** pCFVL = new CegoFieldValue*[pFVL->Size()];
 	CegoFieldValue* pFV = pFVL->First();
-	int i = 0;
+	unsigned i = 0;
 	while ( pFV )
 	{
 	    CegoFieldValue* pCFV = new CegoFieldValue(pFV->getLocalCopy());
@@ -98,9 +98,9 @@ bool CegoQueryCache::QueryCacheEntry::cleanCache()
 	return false;
     }
     
-    for ( int i=0; i<_numRow; i++ )
+    for ( unsigned i=0; i<_numRow; i++ )
     {
-	for ( int j=0; j<_numCol; j++ )
+	for ( unsigned j=0; j<_numCol; j++ )
 	    delete _pCacheArray[i][j];
 	delete _pCacheArray[i];
     }
@@ -133,9 +133,9 @@ void CegoQueryCache::QueryCacheEntry::calcSize()
 	pF = _cacheSchema.Next();
     }
 
-    for ( int i=0; i<_numRow; i++ )
+    for ( unsigned i=0; i<_numRow; i++ )
     {
-	for ( int j=0; j<_numCol; j++ )
+	for ( unsigned j=0; j<_numCol; j++ )
 	{
 	    CegoFieldValue *pF = _pCacheArray[i][j];
 	    _size += pF->size();
@@ -143,12 +143,12 @@ void CegoQueryCache::QueryCacheEntry::calcSize()
     }
 }
 
-int CegoQueryCache::QueryCacheEntry::getSize() const
+unsigned CegoQueryCache::QueryCacheEntry::getSize() const
 {
     return _size;
 }
 
-int CegoQueryCache::QueryCacheEntry::getHashPos(int hashSize) const
+unsigned CegoQueryCache::QueryCacheEntry::getHashPos(unsigned hashSize) const
 {
     return _queryId.getHashPos(hashSize);
 }
@@ -158,12 +158,12 @@ const Chain CegoQueryCache::QueryCacheEntry::getQueryId() const
     return _queryId;
 }
 
-int CegoQueryCache::QueryCacheEntry::getNumRows() const
+unsigned CegoQueryCache::QueryCacheEntry::getNumRows() const
 {
     return _numRow;
 }
 
-int CegoQueryCache::QueryCacheEntry::getNumUsed() const
+unsigned CegoQueryCache::QueryCacheEntry::getNumUsed() const
 {
     return _numUsed;
 }
@@ -222,7 +222,7 @@ bool CegoQueryCache::QueryCacheEntry::operator == ( const CegoQueryCache::QueryC
 // Query Cache Methods //
 /////////////////////////
 
-CegoQueryCache::CegoQueryCache(int tabSetId, int maxEntry, int maxSize, int threshold, int hashRange)
+CegoQueryCache::CegoQueryCache(unsigned tabSetId, unsigned maxEntry, unsigned maxSize, unsigned threshold, unsigned hashRange)
 {
     _cacheLock[tabSetId].init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
     _cacheLock[tabSetId].setId( Chain("QCACHE") + Chain("-") + Chain(tabSetId));
@@ -303,7 +303,7 @@ Element* CegoQueryCache::getCacheInfo()
     pN->setAttribute(XML_VALUE_ATTR, hrFormated);
     pCacheInfo->addContent(pN);
 
-    int numEntry = _pQueryCache->numEntry();
+    unsigned numEntry = _pQueryCache->numEntry();
     pN = new Element(XML_CACHE_ELEMENT);
     pN->setAttribute(XML_ATTRNAME_ATTR, Chain("NumEntry"));
     pN->setAttribute(XML_VALUE_ATTR, Chain(numEntry));
@@ -346,22 +346,22 @@ Element* CegoQueryCache::getCacheList()
     return pCacheInfo;
 }
 
-int CegoQueryCache::getMaxEntry() const
+unsigned CegoQueryCache::getMaxEntry() const
 {
     return _maxEntry;
 }
 
-int CegoQueryCache::getMaxSize() const
+unsigned CegoQueryCache::getMaxSize() const
 {
     return _maxSize;
 }
 
-int CegoQueryCache::getThreshold() const
+unsigned CegoQueryCache::getThreshold() const
 {
     return _threshold;
 }
 
-int CegoQueryCache::getNumQueryCache() const
+unsigned CegoQueryCache::getNumQueryCache() const
 {
     return _pQueryCache->numEntry();
 }
@@ -371,7 +371,7 @@ unsigned long long CegoQueryCache::getUsedSize() const
     return _usedSize;
 }
 
-int CegoQueryCache::getNumFail() const
+unsigned CegoQueryCache::getNumFail() const
 {
     return _numFail;
 }
@@ -380,8 +380,8 @@ void CegoQueryCache::invalidate(const CegoObject& obj)
 {
     bool isClean=false;
 
-    int tryDelay = QUERYCACHE_TRYDELAYBASE;
-    int tryCount = 0;
+    unsigned tryDelay = QUERYCACHE_TRYDELAYBASE;
+    unsigned tryCount = 0;
     
     while ( isClean == false && tryCount < QUERYCACHE_MAXTRY)
     {
@@ -399,14 +399,14 @@ void CegoQueryCache::invalidate(const CegoObject& obj)
 	    {
 		if ( pQCE->getObjectList().Find(obj) )
 		{
-		    int s = pQCE->getSize();
+		    unsigned s = pQCE->getSize();
 		    
 		    if ( pQCE->cleanCache() )
 		    {
 			// cout << "Cache invalition, decreased size from " << _usedSize << " to " << _usedSize - s  << "(" << s << ")" << endl; 
 			_usedSize = _usedSize - s;
 			
-			int pos = _pQueryCache->getPos();
+			unsigned pos = _pQueryCache->getPos();
 			if ( _pQueryCache->RemovePos(pos) == false )
 			{
 			    Chain msg = Chain("Cannot remove query cache entry ") + Chain(pQCE->getQueryId());
@@ -454,7 +454,7 @@ void CegoQueryCache::invalidate(const CegoObject& obj)
     }
 }
 
-CegoFieldValue*** CegoQueryCache::claimEntry(const Chain& queryId, ListT<CegoField>& cacheSchema, int& cacheRows)
+CegoFieldValue*** CegoQueryCache::claimEntry(const Chain& queryId, ListT<CegoField>& cacheSchema, unsigned& cacheRows)
 {
     CegoFieldValue*** pCE = 0;
 
@@ -528,8 +528,8 @@ bool CegoQueryCache::addEntry(const Chain& queryId, const SetT<CegoObject>& obje
 {       
     bool wasInserted = false;
 
-    int tryDelay = QUERYCACHE_TRYDELAYBASE;
-    int tryCount = 0;
+    unsigned tryDelay = QUERYCACHE_TRYDELAYBASE;
+    unsigned tryCount = 0;
     
     while ( wasInserted == false && tryCount < QUERYCACHE_MAXTRY)
     {
@@ -564,7 +564,7 @@ bool CegoQueryCache::addEntry(const Chain& queryId, const SetT<CegoObject>& obje
 	    {
 		QueryCacheEntry *pRE = 0;
 		
-		int pos;
+		unsigned pos;
 		unsigned long minHit = 0;
 		QueryCacheEntry *pQCE = _pQueryCache->FirstInRange(qce);
 		while ( pQCE )
@@ -583,7 +583,7 @@ bool CegoQueryCache::addEntry(const Chain& queryId, const SetT<CegoObject>& obje
 		{
 		    if ( pRE->cleanCache() )
 		    {
-			int s = pRE->getSize();
+			unsigned s = pRE->getSize();
 			_usedSize = _usedSize - s;
 			// cout << "Removing cache entry .." << endl;
 			
@@ -655,7 +655,7 @@ void CegoQueryCache::clean()
 		// so we repeat until cache is clean
 		if ( pQCE->cleanCache() )
 		{
-		    int pos = _pQueryCache->getPos();
+		    unsigned pos = _pQueryCache->getPos();
 		    if ( _pQueryCache->RemovePos(pos) == false )
 		    {
 			Chain msg = Chain("Cannot remove query cache entry ") + Chain(pQCE->getQueryId());
@@ -685,7 +685,7 @@ void CegoQueryCache::clean()
     _usedSize = 0;
 }
 
-void CegoQueryCache::getQCLockStat(int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoQueryCache::getQCLockStat(unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockCount = _cacheLock[_tabSetId].numLockTry();
     
