@@ -47,18 +47,18 @@ class CegoRecoveryManager {
 public:
 
     enum RecoveryMode { LOCAL, REMOTE }; 
-    enum RecoveryState { RECPITREACHED, RECINCOMPLETE, RECOK };
+    enum RecoveryState { RECPITREACHED, RECOK };
 
     CegoRecoveryManager(CegoDistManager *pTabMng, RecoveryMode mode);
     ~CegoRecoveryManager();
 
-    unsigned long long recoverTableSet(const Chain& tableSet, long long pit, CegoAdminHandler* pAH);
-    RecoveryState recoverCurrentTransactionLog(unsigned tabSetId, long long pit, unsigned long long& lsn, long long& ts);
+    unsigned long long recoverTableSet(const Chain& tableSet, long long pit, unsigned long long targetlsn, CegoAdminHandler* pAH);
+    RecoveryState recoverCurrentTransactionLog(unsigned tabSetId, long long pit, unsigned long long targetlsn, unsigned long long& reachlsn, long long& ts);
     
 private:
 
     unsigned long long dataFileRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long  lsn, CegoAdminHandler* pAH);
-    unsigned long long transactionRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long cplsn, long long pit, CegoAdminHandler* pAH);
+    unsigned long long transactionRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long cplsn, long long pit, unsigned long long targetlsn, CegoAdminHandler* pAH);
     unsigned long long recoverCurrentDataFileLog(unsigned tabSetId, bool& endOfBackup);
     bool restoreLogFile(const Chain& tableSet, unsigned long lsn);
     
