@@ -30,11 +30,11 @@ public:
     CegoSystemObject(CegoDatabaseManager *pDBMng);
     ~CegoSystemObject();
 
-    void createSystemSpace(int tabSetId);
-    bool objectExists(int tabSetId, const Chain& objectName, CegoObject::ObjectType type);
-    void getObject(int tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe);
-    void getObjectWithFix(int tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe, CegoBufferPage &bp);
-    void getObjectList(int tabSetId, CegoObject::ObjectType type, ListT<Chain>& objList);
+    void createSystemSpace(unsigned tabSetId);
+    bool objectExists(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type);
+    void getObject(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe);
+    void getObjectWithFix(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe, CegoBufferPage &bp);
+    void getObjectList(unsigned tabSetId, CegoObject::ObjectType type, ListT<Chain>& objList);
 
 private:
         
