@@ -34,8 +34,8 @@ public:
     
     CegoTableObject();
     CegoTableObject(const CegoTableObject& oe);
-    CegoTableObject(int tabSetId, ObjectType type, const Chain& objName);
-    CegoTableObject(int tabSetId, ObjectType type, const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName);
+    CegoTableObject(unsigned tabSetId, ObjectType type, const Chain& objName);
+    CegoTableObject(unsigned tabSetId, ObjectType type, const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName);
     ~CegoTableObject();
     
     void setDataPageId(PageIdType pageId);
@@ -44,15 +44,15 @@ public:
     PageIdType getLastDataPageId() const;
     void setRefLastDataPageId(PageIdType pageId);
     PageIdType getRefLastDataPageId() const;
-    void setMaxFid(int maxFid);
-    int getMaxFid() const;
-    int getEntrySize() const;
+    void setMaxFid(unsigned maxFid);
+    unsigned getMaxFid() const;
+    unsigned getEntrySize() const;
     void encode(char *buf) const;
     void decode(char *buf);
     bool isValid(); 
     void setSchema(const ListT<CegoField>& schema);   
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
     CegoContentObject* clone(bool isAttrRef = false);    
     Chain getInfo() const;
     
@@ -64,6 +64,6 @@ private:
     PageIdType _pageId;
     char* _pLastPageId;
     PageIdType _lastPageId;
-    int _maxFid;
+    unsigned _maxFid;
 };
 #endif
