@@ -38,13 +38,13 @@ public:
     enum TermType { MUL, DIV, FACTOR  };
     
     CegoTerm();
-    CegoTerm(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoTerm(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoTerm(CegoTerm *pTerm, CegoFactor *pFac, TermType termType);
     CegoTerm(CegoFactor *pFactor);
     ~CegoTerm();
 
     void cleanUp();
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     void clearAttrCache();
     void getFunctionList(SetT<CegoObject>& funcList);
     void getSelectQueryList(ListT<CegoSelect*>& queryList);
@@ -55,7 +55,7 @@ public:
     bool checkLob(CegoFieldValue& fv, CegoProcBlock *pBlock);
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField> **pFLA) const;
     ListT<CegoAttrDesc*> getAttrRefList() const;
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
     CegoField evalField(const ListT<CegoField>& fl, bool graceful = false) const;
 
     CegoFieldValue evalFieldValue(ListT<CegoField> **pFLA, CegoProcBlock *pBlock) const;
@@ -66,12 +66,12 @@ public:
     ListT<CegoAggregation*> getAggregationList();
     CegoTerm* clone(bool isAttrRef = false);
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId, const Chain& indent) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void getPlanList(ListT<Element*>& planList);
 
