@@ -34,11 +34,11 @@ public:
     
     CegoViewObject();
     CegoViewObject(const CegoViewObject& vo);
-    CegoViewObject(const Chain& viewName, int tabSetId = 0);
-    CegoViewObject(int tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewStmt);
+    CegoViewObject(const Chain& viewName, unsigned tabSetId = 0);
+    CegoViewObject(unsigned tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewStmt);
     ~CegoViewObject();
     
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
     void encode(char *buf) const;
     void decode(char *buf);
     void setSchema(const ListT<CegoField>& schema);
@@ -46,7 +46,7 @@ public:
     void setViewStmt(const Chain& viewStmt);
     void setEmpty();
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
     CegoContentObject* clone(bool isAttrRef=false);
     Chain getInfo() const;
 
